## [0.3.1](https://github.com/CellProfiling/cam_acq/tree/0.3.1) (2018-05-23)
[Full Changelog](https://github.com/CellProfiling/cam_acq/compare/0.3...0.3.1)

**Merged pull requests:**

- 0.3.1 [\#81](https://github.com/CellProfiling/cam_acq/pull/81) ([MartinHjelmare](https://github.com/MartinHjelmare))

## [0.3](https://github.com/CellProfiling/cam_acq/tree/0.3) (2017-08-18)
[Full Changelog](https://github.com/CellProfiling/cam_acq/compare/0.2...0.3)

**Breaking Changes:**

- Make settings configurable from config [\#31](https://github.com/CellProfiling/cam_acq/pull/31) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Allow DNS for host [\#29](https://github.com/CellProfiling/cam_acq/pull/29) ([MartinHjelmare](https://github.com/MartinHjelmare))

**Merged pull requests:**

- 0.3 [\#34](https://github.com/CellProfiling/cam_acq/pull/34) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update readme with latest option changes [\#33](https://github.com/CellProfiling/cam_acq/pull/33) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Move version to const.py [\#32](https://github.com/CellProfiling/cam_acq/pull/32) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix setting log level via cmd line or config file [\#30](https://github.com/CellProfiling/cam_acq/pull/30) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix bugs [\#28](https://github.com/CellProfiling/cam_acq/pull/28) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add port option [\#27](https://github.com/CellProfiling/cam_acq/pull/27) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix rst nested bullet syntax in readme [\#26](https://github.com/CellProfiling/cam_acq/pull/26) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update readme with install and run instructions [\#25](https://github.com/CellProfiling/cam_acq/pull/25) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix missing package data [\#24](https://github.com/CellProfiling/cam_acq/pull/24) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix logging [\#23](https://github.com/CellProfiling/cam_acq/pull/23) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix typo in contributing instruction [\#22](https://github.com/CellProfiling/cam_acq/pull/22) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add contributing instructions [\#21](https://github.com/CellProfiling/cam_acq/pull/21) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add entry\_points instead of scripts [\#20](https://github.com/CellProfiling/cam_acq/pull/20) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix template rendering [\#19](https://github.com/CellProfiling/cam_acq/pull/19) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Merge command line arguments into config dict [\#18](https://github.com/CellProfiling/cam_acq/pull/18) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix bugs [\#17](https://github.com/CellProfiling/cam_acq/pull/17) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update tox travis section to not deprecated style [\#16](https://github.com/CellProfiling/cam_acq/pull/16) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add tests for command module [\#15](https://github.com/CellProfiling/cam_acq/pull/15) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Refactor/eventbus [\#14](https://github.com/CellProfiling/cam_acq/pull/14) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix rst syntax in readme [\#13](https://github.com/CellProfiling/cam_acq/pull/13) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add tox testing and linting [\#12](https://github.com/CellProfiling/cam_acq/pull/12) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add Well class and refactor to use the new class [\#11](https://github.com/CellProfiling/cam_acq/pull/11) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add template feature using jinja [\#10](https://github.com/CellProfiling/cam_acq/pull/10) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Refactor control method in Control class [\#9](https://github.com/CellProfiling/cam_acq/pull/9) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Refactor image module and handling [\#8](https://github.com/CellProfiling/cam_acq/pull/8) ([MartinHjelmare](https://github.com/MartinHjelmare))

## [0.2](https://github.com/CellProfiling/cam_acq/tree/0.2) (2017-01-19)
**Merged pull requests:**

- 0.2 [\#7](https://github.com/CellProfiling/cam_acq/pull/7) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Bug fixes [\#6](https://github.com/CellProfiling/cam_acq/pull/6) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Use matrixscreener package and api [\#5](https://github.com/CellProfiling/cam_acq/pull/5) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add Sphinx docs and version string [\#4](https://github.com/CellProfiling/cam_acq/pull/4) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add formatting function [\#2](https://github.com/CellProfiling/cam_acq/pull/2) ([cwinsnes](https://github.com/cwinsnes))
